@@ -12,7 +12,7 @@
 
 # information
 __author__ = "Oskar Maier"
-__version__ = "0.1, 2011-12-11"
+__version__ = "0.2, 2011-12-11"
 __email__ = "oskar.maier@googlemail.com"
 __status__ = "Development"
 __description__ = """
@@ -25,8 +25,6 @@ class ArgumentError(Exception):
     Thrown by an application when an invalid command line argument has been supplied.
     """
     pass
-    #def __init__(self, message, exception = None):
-    #    Exception.__init__(message, exception)
     
 class FunctionError(Exception):
     """
@@ -63,4 +61,9 @@ class ImageSavingError(Exception):
     Thrown when a image could not be loaded.
     """
     pass
-        
\ No newline at end of file
+
+class MetaDataError(Exception):
+    """
+    Thrown when an image meta data failure occurred.
+    """
+    pass
\ No newline at end of file
