@@ -7,7 +7,7 @@ Provides functionalities for loading, saving and manipulating images.
 Modules:
     - load: Functionality for loading images.
     - save: Functionality for saving images.
-    - imageheader: Image header object.
+    - header: Image header manipulation routines.
 """
 
 # determines the modules that should be imported when "from metric import *" is used
@@ -16,4 +16,4 @@ __all__ = []
 # if __all__ is not set, only the following, explicit import statements are executed
 from load import load
 from save import save
-from header import get_pixel_spacing
\ No newline at end of file
+from header import get_pixel_spacing, get_offset, set_pixel_spacing, set_offset, copy_meta_data
\ No newline at end of file
